<?php

namespace Pogodi\Product;

use DateTime;
use Nette\Database\Context;
use Nette\Object;

/**
 * Class Warehouse
 * @package Pogodi\Product
 */
class Warehouse extends Object
{

    const TABLE_NAME = 'product_warehouse';

    /**
     * @var int
     */
    protected $product_id;

    /**
     * @var array
     */
    protected $warehouses;

    /**
     * @var array
     */
    protected $toDelete;

    /**
     * @var array
     */
    protected $toUpdate;

    /**
     * @var Context
     */
    protected $database;


    function __construct(Context $database)
    {
        $this->database = $database;
        $this->warehouses = [];
        $this->toDelete = [];
        $this->toUpdate = [];
    }

    public function loadById($product_id)
    {
        $rows = $this->database->table(self::TABLE_NAME)->where('product_id', $product_id)->fetchAll();
        foreach ($rows as $row) {
            $this->warehouses[$row['warehouse_id']] = [
                'id' => $row['id'],
                'product_id' => $row['product_id'],
                'warehouse_id' => $row['warehouse_id'],
                'total' => $row['total'],
                'updated' => $row['updated'],
            ];
        }
        $this->product_id = $product_id;
    }

    public function getAll()
    {
        return $this->warehouses;
    }

    public function getWarehouseTotal($warehouse_id)
    {
        if (isset($this->warehouses[$warehouse_id])) {
            return $this->warehouses[$warehouse_id]['total'];
        }

        return 0;
    }

    public function addWarehouse($warehouse_id, $total)
    {
        $this->warehouses[] = [
            'id' => NULL,
            'product_id' => $this->product_id,
            'warehouse_id' => $warehouse_id,
            'total' => $total,
            'updated' => new DateTime(),
        ];
    }

    public function updateWarehouse($warehouse_id, $total)
    {
        if (!isset($this->warehouses[$warehouse_id])) {
            throw new \InvalidArgumentException("Warehouse with ID: '$warehouse_id' not exist.");
        }
        $this->warehouses[$warehouse_id]['total'] = $total;
        $this->warehouses[$warehouse_id]['updated'] = new DateTime();
        $this->toUpdate[] = $warehouse_id;
    }

    public function deleteWarehouse($warehouse_id)
    {
        if (!isset($this->warehouses[$warehouse_id])) {
            throw new \InvalidArgumentException("Warehouse with ID: '$warehouse_id' not exist.");
        }
        $this->toDelete[] = $this->warehouses[$warehouse_id]['id'];
    }

    public function save()
    {
        foreach ($this->warehouses as $key => $warehouse) {
            if (NULL === $warehouse['id'] || in_array($warehouse['warehouse_id'], $this->toUpdate)) {
                if (NULL === $warehouse['id']) {
                    $id = $this->_add($warehouse['warehouse_id'], $warehouse['total']);
                    $this->warehouses[$key]['id'] = $id;
                } else {
                    $this->_edit($warehouse['id'], $warehouse['warehouse_id'], $warehouse['total']);
                }

            }
        }

        foreach ($this->toDelete as $delete_id) {
            $this->database->table(self::TABLE_NAME)->where('id', $delete_id)->delete();
        }
    }

    public function setProductId($product_id)
    {
        $this->product_id = $product_id;
    }

    protected function _add($warehouse_id, $total)
    {
        $row = $this->database->table(self::TABLE_NAME)->insert([
            'product_id' => $this->product_id,
            'warehouse_id' => $warehouse_id,
            'total' => $total,
            'updated' => new DateTime(),
        ]);
        return $row['id'];
    }

    protected function _edit($id, $warehouse_id, $total)
    {
        $this->database->table(self::TABLE_NAME)->where('id', $id)->update([
            'warehouse_id' => $warehouse_id,
            'total' => $total,
            'updated' => new DateTime(),
        ]);
    }

}
