<?php

namespace Pogodi;


class WarehouseManager extends AbstractManager
{

    const
        TABLE_NAME = 'warehouse',
        COLUMN_ID = 'id',
        COLUMN_CODE = 'code',
        COLUMN_TITLE = 'title',
        COLUMN_STREET = 'street',
        COLUMN_CITY = 'city',
        COLUMN_POSTCODE = 'postcode',
        COLUMN_LAT = 'lat',
        COLUMN_LON = 'lon';

    /**
     * @var array
     */
    protected $memoryCache;

    protected function startup()
    {
        parent::startup();
        $this->memoryCache = [];
    }


    public function getAll($flushCache = false)
    {
        $key = 'getAllWarehouses';
        if (empty($this->memoryCache[$key]) || $flushCache) {
            $this->memoryCache[$key] = $this->database->table(self::TABLE_NAME)->order(self::COLUMN_TITLE)->fetchAll();
        }

        return $this->memoryCache[$key];
    }

    public function getById($id)
    {
        $res = $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $id)->fetch();
        if ($res) {
            return $res;
        }
        return FALSE;
    }

    public function getByCode($code)
    {
        $res = $this->database->table(self::TABLE_NAME)->where(self::COLUMN_CODE, $code)->fetch();
        if ($res) {
            return $res;
        }
        return FALSE;
    }

    public function insert($data)
    {
        $row = $this->database->table(self::TABLE_NAME)->insert($data);
        return $row[self::COLUMN_ID];
    }

    public function update($id, $data)
    {
        $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $id)->update($data);
    }

    public function delete($id)
    {
        $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $id)->delete();
    }
}