<?php

namespace Pogodi\Brain\Presenters;


use Nette\Application\UI\Form;
use Pogodi\CategoryManager;

class CategoryPresenter extends BasePresenter
{

    /**
     * @var CategoryManager @inject
     */
    public $categoryManager;

    public function renderDefault()
    {
        $this->template->categories = $this->categoryManager->getAll();
    }

    public function renderForm($id = NULL)
    {
        $newCategory = TRUE;
        if ($id) {
            /** @var Form $form */
            $form = $this['categoryForm'];
            $category = $this->categoryManager->getById($id);
            $form->setDefaults([
                'category_id' => $category['id'],
                'title' => $category['title'],
            ]);
            $newCategory = FALSE;
        }
        $this->template->newCategory = $newCategory;
    }

    public function createComponentCategoryForm()
    {
        $form = new Form();
        $form->addText("title", "Title: ")
            ->setRequired();
        $form->addSubmit('ok', 'Save');
        $form->addHidden('category_id');
        $form->onSuccess[] = $this->categoryFormSubmitted;
        return $form;
    }

    public function categoryFormSubmitted(Form $form)
    {
        $values = $form->getValues();
        if ($values->category_id) {
            $this->categoryManager->update($values->category_id, $values->title);
            $this->flashMessage('Category was successfully updated.', 'success');
        } else {
            $this->categoryManager->insert($values->title);
            $this->flashMessage('New category was successfully created.', 'success');
        }
        $this->redirect('default');
    }

    public function actionDelete($category_id)
    {
        $this->categoryManager->delete($category_id);
        $this->flashMessage('Category was successfully  deleted.', 'success');
        $this->redirect('default');
    }

}