<?php

namespace Pogodi\Brain\Presenters;


use Nette\Application\UI\Form;
use Pogodi\BrandManager;
use Pogodi\CategoryManager;
use Pogodi\Product\ProductFactory;
use Pogodi\Product\ProductManager;
use Pogodi\WarehouseManager;

class ProductPresenter extends BasePresenter
{

    /**
     * @var ProductFactory @inject
     */
    public $productFactory;

    /**
     * @var ProductManager @inject
     */
    public $productManager;

    /**
     * @var CategoryManager @inject
     */
    public $categoryManager;

    /** @var BrandManager @inject */
    public $brandManager;

    /**
     * @var WarehouseManager @inject
     */
    public $warehouseManager;

    public function renderDefault()
    {
        $this->template->products = $this->productManager->getLastUpdatedProducts();
    }

    public function createComponentCreateProductForm()
    {
        $form = new Form();
        $form->addText('title', 'Title')
            ->setRequired("Title have to be filled");
        $form->addText('sku', 'Sku')
            ->addRule(Form::INTEGER, "Sku must be number.");
        $form->addText('price', 'Price')
            ->addRule(Form::INTEGER, "Price must be number.");
        $form->addSelect("category", "Category", $this->getCategoriesToSelect())
            ->setPrompt("Please select category")
            ->setRequired('Category have to be filled');
        $form->addSelect('brand', 'Brand', $this->getBrandsToSelect())
            ->setPrompt('Please select brand');
        $form->addCheckbox('active', 'Active');
        $form->addSubmit('ok', 'Create new product');
        $form->onSuccess[] = $this->createProductFormSubmitted;
        return $form;
    }

    public function createProductFormSubmitted(Form $form)
    {
        $values = $form->getValues();
        $product = $this->productFactory->createProduct();
        $product->setTitle($values->title);
        $product->setSku($values->sku);
        $product->setPrice($values->price);
        $product->setActive($values->active);
        $product->setCategoryId($values->category);
        $product->setBrandId($values->brand);
        $product->save();
        $this->flashMessage("Product has benn created.", "success");
        $this->redirect("default");
    }

    public function renderEdit($product_id)
    {
        $product = $this->productFactory->createProduct();
        $product->loadById($product_id);
        $warehouses = $this->warehouseManager->getAll();

        $default = [];
        foreach ($warehouses as $warehouse) {
            $default['warehouse_' . $warehouse['id']] = $product->getWarehouses()->getWarehouseTotal($warehouse['id']);
        }

        /** @var Form $form */
        $form = $this['editProductForm'];
        $form->setDefaults($default + [
                'product_id' => $product->getId(),
                'title' => $product->getTitle(),
                'sku' => $product->getSku(),
                'price' => $product->getPrice(),
                'active' => $product->isActive(),
                'category' => $product->getCategory()->getId(),
                'brand' => $product->getBrand()->getId(),
            ]);

        $this->template->warehouses = $warehouses;
    }

    public function createComponentEditProductForm()
    {
        $form = $this->createComponentCreateProductForm();
        $form->addHidden('product_id');
        $warehouses = $this->warehouseManager->getAll();
        foreach ($warehouses as $warehouse) {
            $form->addText('warehouse_' . $warehouse['id'], $warehouse['title'])
                ->addRule(Form::INTEGER);
        }
        $form->onSuccess = [$this->editProductFormSubmitted];
        return $form;
    }

    public function editProductFormSubmitted(Form $form)
    {
        $values = $form->getValues();
        $product = $this->productFactory->createProduct();
        $product->loadById((int)$values['product_id']);
        $product->setTitle($values->title);
        $product->setSku($values->sku);
        $product->setPrice($values->price);
        $product->setActive($values->active);
        $product->setCategoryId($values->category);
        $product->setBrandId($values->brand);

        $warehouses = $this->warehouseManager->getAll();
        foreach ($warehouses as $warehouse) {
            $warehouse_id = $warehouse['id'];
            $id = 'warehouse_' . $warehouse_id;
            $total = (int)$values[$id];
            if ($total !== 0) {
                if ($product->getWarehouses()->getWarehouseTotal($warehouse_id) > 0) {
                    $product->getWarehouses()->updateWarehouse($warehouse_id, $total);
                } else {
                    $product->getWarehouses()->addWarehouse($warehouse_id, $total);
                }
            } else {
                if ($product->getWarehouses()->getWarehouseTotal($warehouse_id) > 0) {
                    $product->getWarehouses()->deleteWarehouse($warehouse_id);
                }
            }
        }

        $product->save();
        $this->flashMessage("Product has been successfully updated.", "success");
        $this->redirect("this");
    }

    public function actionDelete($product_id)
    {
        $product = $this->productFactory->createProduct();
        $product->loadById((int)$product_id);
        $product->delete();
        $this->flashMessage("Product has been successfully deleted.", "success");
        $this->redirect('default');
    }

    private function getCategoriesToSelect()
    {
        $categories = $this->categoryManager->getAll();
        $result = [];
        foreach ($categories as $category) {
            $result[$category['id']] = $category['title'];
        }
        return $result;
    }

    public function getBrandsToSelect()
    {
        $brands = $this->brandManager->getAll();
        $result = [];
        foreach ($brands as $brand) {
            $result[$brand['id']] = $brand['title'];
        }
        return $result;
    }

}