<?php

namespace Pogodi\Brain\Presenters;


use Nette\Application\UI\Form;
use Pogodi\WarehouseManager;

class WarehousePresenter extends BasePresenter
{

    /**
     * @var WarehouseManager @inject
     */
    public $warehouseManager;

    public function renderDefault()
    {
        $this->template->warehouses = $this->warehouseManager->getAll();
    }

    public function renderDetail($id)
    {
        $this->template->warehouse = $this->warehouseManager->getById($id);
    }

    public function renderForm($id = NULL)
    {
        $newWarehouse = TRUE;
        if ($id) {
            /** @var Form $form */
            $form = $this['warehouseForm'];
            $row = $this->warehouseManager->getById($id);
            $form->setDefaults([
                'warehouse_id' => $row[WarehouseManager::COLUMN_ID],
                'code' => $row[WarehouseManager::COLUMN_CODE],
                'title' => $row[WarehouseManager::COLUMN_TITLE],
                'street' => $row[WarehouseManager::COLUMN_STREET],
                'city' => $row[WarehouseManager::COLUMN_CITY],
                'postcode' => $row[WarehouseManager::COLUMN_POSTCODE],
                'lat' => $row[WarehouseManager::COLUMN_LAT],
                'lon' => $row[WarehouseManager::COLUMN_LON],
            ]);
            $newWarehouse = FALSE;
        }
        $this->template->newWarehouse = $newWarehouse;
    }

    public function createComponentWarehouseForm()
    {
        $form = new Form();
        $form->addText('code', 'Code')
            ->setRequired();
        $form->addText('title', 'Title')
            ->setRequired();
        $form->addText('street', 'Street');
        $form->addText('city', 'City');
        $form->addText('postcode', 'Postcode');
        $form->addText('lat', 'Latitude');
        $form->addText('lon', 'Longitude');
        $form->addHidden('warehouse_id');
        $form->addSubmit('ok', 'Save');
        $form->onSuccess[] = $this->warehouseFormSubmitted;
        return $form;
    }

    public function warehouseFormSubmitted(Form $form)
    {
        $values = $form->getValues();
        $data = [
            WarehouseManager::COLUMN_CODE => $values->code,
            WarehouseManager::COLUMN_TITLE => $values->title,
            WarehouseManager::COLUMN_STREET => $values->street,
            WarehouseManager::COLUMN_CITY => $values->city,
            WarehouseManager::COLUMN_POSTCODE => $values->postcode,
            WarehouseManager::COLUMN_LAT => $values->lat,
            WarehouseManager::COLUMN_LON => $values->lon,
        ];
        if ($values->warehouse_id) {
            $this->warehouseManager->update($values->warehouse_id, $data);
            $this->flashMessage('Warehouse has been successfully updated.', 'success');
        } else {
            $this->warehouseManager->insert($data);
            $this->flashMessage('Warehouse has been successfully created.', 'success');
        }
        $this->redirect('default');
    }

    public function actionDelete($id)
    {
        $this->warehouseManager->delete($id);
        $this->flashMessage('Warehouse has been successfully deleted.', 'success');
        $this->redirect('default');
    }

}