<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Pogodi\Product\Product;
use Pogodi\Product\ProductFactory;
use Tester\Assert;

/** @var Container $container */
$container = require __DIR__ . "/../../bootstrap.php";

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');

/** @var ProductFactory $productFactory */
$productFactory = $container->getByType('Pogodi\Product\ProductFactory');

purge($databaseContext);
Helpers::loadFromFile($connection, __DIR__ . "/sql/product.sql");

Assert::true($productFactory->createProduct() instanceof Product);

$product1 = $productFactory->createProduct();
$product1->setSku("12345678");
$product1->setTitle('product1');
$product1->setCategoryId(1); // in insert script
$product1->setBrandId(1); // in insert script
$product1->setPrice(140);
$product1->setActive(TRUE);
$product1->save();
$id1 = $product1->getId();
$product1_c = $productFactory->createProduct();

$product1_c->loadById($id1);
Assert::true($product1->getId() > 0);
Assert::equal($product1->getId(), $product1_c->getId());
Assert::equal($product1->getSku(), $product1_c->getSku());
Assert::equal($product1->getTitle(), $product1_c->getTitle());
Assert::equal($product1->getCategory()->getId(), $product1_c->getCategory()->getId());
Assert::equal($product1->getPrice(), $product1_c->getPrice());
Assert::equal("Adidas", $product1_c->getBrand()->getTitle());
Assert::equal(1, $product1_c->getBrand()->getId());
Assert::equal("12345678", $product1_c->getSku());
Assert::equal($product1->isActive(), $product1_c->isActive());
Assert::true($product1_c->getCreated() instanceof DateTime);
Assert::true($product1_c->getUpdated() instanceof DateTime);


$product2 = $productFactory->createProduct();
$product2->setSku("87654321");
$product2->setTitle('product2');
$product2->setCategoryId(1); // in insert script
$product2->setBrandId(NULL);
$product2->setPrice(740);
$product2->setActive(FALSE);
$product2->save();
$id2 = $product2->getId();
$product2_c1 = $productFactory->createProduct();
$product2_c1->loadById($id2);
// update test
Assert::equal("87654321", $product2_c1->getSku());
$product2->setSku("ABCDEFGH");
$product2->setActive(FALSE);
$product2->save();
$product2_c2 = $productFactory->createProduct();
$product2_c2->loadById($id2);
Assert::equal("ABCDEFGH", $product2_c2->getSku());
Assert::false($product2_c2->isActive());
//delete
$product2->delete();
Assert::exception(function () use ($productFactory, $id2) {
    $noExistProduct = $productFactory->createProduct();
    $noExistProduct->loadById($id2);
}, 'InvalidArgumentException');


// no ID load
Assert::exception(function () use ($productFactory) {
    $product = $productFactory->createProduct();
    $product->loadById('Iamnotexist');
}, 'InvalidArgumentException');

// no ID delete
Assert::exception(function () use ($productFactory, $id2) {
    $product = $productFactory->createProduct();
    $product->delete();
}, 'InvalidArgumentException');