<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Pogodi\Product\ProductFactory;
use Tester\Assert;

/** @var Container $container */
$container = require __DIR__ . "/../../bootstrap.php";

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');

/** @var ProductFactory $productFactory */
$productFactory = $container->getByType('Pogodi\Product\ProductFactory');

purge($databaseContext);
Helpers::loadFromFile($connection, __DIR__ . "/sql/product.sql");

$p = $productFactory->createProduct();
$p->setSku("B1234567");
$p->setTitle('asd');
$p->setCategoryId(1); // from insert script
$p->setPrice(10);
$p->setActive(TRUE);
$w = $p->getWarehouses();
$w->addWarehouse(1, 21);
$w->addWarehouse(2, 13);
$p->save();
$id = $p->getId();
Assert::true($id > 0);


$productTest1 = $productFactory->createProduct();
$productTest1->loadById($id);
$ws = $productTest1->getWarehouses()->getAll();
Assert::true(count($ws) === 2); // 2 warehouses
Assert::equal($ws['1']['total'], 21);
Assert::equal($ws['2']['total'], 13);
Assert::equal($productTest1->getWarehouses()->getWarehouseTotal(1), 21);
Assert::equal($productTest1->getWarehouses()->getWarehouseTotal(2), 13);
Assert::equal($productTest1->getWarehouses()->getWarehouseTotal(99), 0); // no warehouse

// update product warehouses
$productTest1->getWarehouses()->updateWarehouse(1, 15);
$productTest1->getWarehouses()->updateWarehouse(2, 1774);
$productTest1->save();

$productTest2 = $productFactory->createProduct();
$productTest2->loadById($id);
$ws = $productTest2->getWarehouses()->getAll();
Assert::true(count($ws) === 2); // 2 warehouses
Assert::equal($ws['1']['total'], 15);
Assert::equal($ws['2']['total'], 1774);
Assert::equal($productTest2->getWarehouses()->getWarehouseTotal(1), 15);
Assert::equal($productTest2->getWarehouses()->getWarehouseTotal(2), 1774);
Assert::equal($productTest2->getWarehouses()->getWarehouseTotal(99), 0); // no warehouse

// delete warehouse
$productTest3 = $productFactory->createProduct();
$productTest3->loadById($id);
$productTest3->getWarehouses()->deleteWarehouse(1);
$productTest3->save();
$productTest4 = $productFactory->createProduct();
$productTest4->loadById($id);
Assert::equal(1, count($productTest4->getWarehouses()->getAll()));
$ws = $productTest4->getWarehouses()->getAll();
Assert::false(isset($ws['1']));
Assert::equal($ws['2']['total'], 1774);
Assert::equal($productTest4->getWarehouses()->getWarehouseTotal(1), 0); // deleted warehouse
Assert::equal($productTest4->getWarehouses()->getWarehouseTotal(2), 1774);

// bad warehouse ( warehouse with id: 74 not exist )
$productTest5 = $productFactory->createProduct();
$productTest5->loadById($id);
Assert::exception(function () use ($productTest5) {
    $productTest5->getWarehouses()->updateWarehouse(74, 12);
}, 'InvalidArgumentException');
Assert::exception(function () use ($productTest5) {
    $productTest5->getWarehouses()->deleteWarehouse(74, 12);
}, 'InvalidArgumentException');