<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Pogodi\WarehouseManager;
use Tester\Assert;

/** @var Container $container */
$container = require __DIR__ . "/../bootstrap.php";

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');

/** @var WarehouseManager $warehouseManager */
$warehouseManager = $container->getByType('Pogodi\WarehouseManager');

purge($databaseContext);
Helpers::loadFromFile($connection, __DIR__ . "/test_sql/warehouse.sql");

$data1 = [
    'code' => 'WHZ01',
    'title' => 'Warehouse Home1',
    'street' => 'Street1',
    'city' => 'City1',
    'postcode' => 'PostCODE1',
    'lat' => '49.125479',
    'lon' => '-12.567862',
];

$data2 = [
    'code' => 'WHZ02',
    'title' => 'Warehouse Home2',
    'street' => 'Street2',
    'city' => 'City2',
    'postcode' => 'PostCODE2',
    'lat' => '49.12564646',
    'lon' => '-12.586542',
];

$data3 = [
    'code' => 'WHZ03',
    'title' => 'Warehouse Home3',
    'street' => 'Street3',
    'city' => 'City3',
    'postcode' => 'PostCODE3',
    'lat' => '49.1254179',
    'lon' => '-112.567862',
];

$data_update = [
    'code' => 'WHZ01_U',
    'title' => 'Warehouse Home update',
    'street' => 'Street update',
    'city' => 'City update',
    'postcode' => 'PostCODEU',
    'lat' => '49.78214',
    'lon' => '-127.1567862',
];

$id1 = $warehouseManager->insert($data1);
$id2 = $warehouseManager->insert($data2);
$id3 = $warehouseManager->insert($data3);

Assert::true($id1 > 0);
Assert::true($id2 > 0);
Assert::true($id3 > 0);

$row = $warehouseManager->getById($id1);
Assert::equal($data1['code'], $row['code']);
Assert::equal($data1['title'], $row['title']);
Assert::equal($data1['street'], $row['street']);
Assert::equal($data1['city'], $row['city']);
Assert::equal($data1['postcode'], $row['postcode']);
Assert::equal($data1['lat'], $row['lat']);
Assert::equal($data1['lon'], $row['lon']);

$all = $warehouseManager->getAll();
Assert::equal(3, count($all));

$warehouseManager->delete($id3);

// cache test
$all = $warehouseManager->getAll();
Assert::equal(3, count($all));

// cache flushed
$all = $warehouseManager->getAll(TRUE);
Assert::equal(2, count($all));

$row = $warehouseManager->getByCode($data2['code']);
Assert::equal($data2['code'], $row['code']);
Assert::equal($data2['title'], $row['title']);
Assert::equal($data2['street'], $row['street']);
Assert::equal($data2['city'], $row['city']);
Assert::equal($data2['postcode'], $row['postcode']);
Assert::equal($data2['lat'], $row['lat']);
Assert::equal($data2['lon'], $row['lon']);

$warehouseManager->update($id1, $data_update);
$row = $warehouseManager->getById($id1);
Assert::equal($data_update['code'], $row['code']);
Assert::equal($data_update['title'], $row['title']);
Assert::equal($data_update['street'], $row['street']);
Assert::equal($data_update['city'], $row['city']);
Assert::equal($data_update['postcode'], $row['postcode']);
Assert::equal($data_update['lat'], $row['lat']);
Assert::equal($data_update['lon'], $row['lon']);
