<?php

namespace OpencartAPI\Server\Model;


use Nette\Application\IResponse;
use Nette\Http\IRequest;
use Nette\InvalidArgumentException;
use Nette\Utils\Json;

class JsonResponse implements IResponse
{
    /** @var array|\stdClass */
    private $payload;

    /** @var string */
    private $contentType;

    /** @var bool */
    private $error = FALSE;

    /** @var string */
    private $errorMessage;


    /**
     * @param array|\stdClass payload
     * @param string $contentType
     */
    public function __construct($payload = NULL, $contentType = NULL)
    {
        if (!is_array($payload) && !is_object($payload) && !is_null($payload)) {
            throw new InvalidArgumentException(sprintf('Payload must be array or object class, %s given.', gettype($payload)));
        }
        $this->payload = $payload;
        $this->contentType = $contentType ? $contentType : 'application/json';
        $this->errorMessage = "";
    }

    /**
     * @param string $message
     */
    public function setError($message)
    {
        $this->error = TRUE;
        $this->errorMessage = $message;
    }


    /**
     * Sends response to output.
     * @return void
     */
    public function send(IRequest $httpRequest, \Nette\Http\IResponse $httpResponse)
    {
        if ($this->error) {
            $this->payload = [
                'error' => TRUE,
                'message' => $this->errorMessage,
            ];
        } else {
            $this->payload['error'] = FALSE;
        }

        $httpResponse->setContentType($this->contentType);
        $httpResponse->setExpiration(FALSE);
        echo Json::encode($this->payload);
    }


}