<?php

namespace OpencartAPI\Server\Model\Order;


use Nette\Application\BadRequestException;
use Nette\Database\Context;
use OpencartAPI\Server\Model\BaseManager;
use OpencartAPI\Server\Model\Product\ProductManager;

class OrderManager extends BaseManager
{


    const CREDIT_CARD = 3;

    /**
     * @var array
     */
    private $config;

    /**
     * @var ProductManager
     */
    private $productModel;

    /**
     * @var array
     */
    private $ids;

    /**
     * @var array
     */
    private $data;

    /**
     * @var string
     */
    private $lang;

    public function __construct(Context $context, ProductManager $products)
    {
        parent::__construct($context);
        $this->productModel = $products;
        $this->data = array();
        $this->loadConfig();
    }

    public function createOrder($language, $products, $customer)
    {
        $this->lang = $language;
        foreach ($products as $product) {
            $this->ids[] = $product['id'];
        }
        $total = 10;
        $order = array(
            'invoice_no' => 0,
            'invoice_prefix' => '',
            'store_id' => 0,
            'store_name' => "New name",
            'store_url' => "testing store",
            'firstname' => $customer['firstname'],
            'lastname' => $customer['lastname'],
            'email' => $customer['email'],
            'telephone' => $customer['telephone'],
            'fax' => '',
            'custom_field' => 'a:0:{}',
            'payment_firstname' => $customer['firstname'],
            'payment_lastname' => $customer['lastname'],
            'payment_company' => "",
            'payment_address_1' => $customer['address'],
            'payment_address_2' => "",
            'payment_city' => $customer['city'],
            'payment_postcode' => $customer['postcode'],
            'payment_country' => "Czech Republic",
            'payment_country_id' => 56,
            'payment_zone' => "",
            'payment_zone_id' => 0,
            'payment_address_format' => "",
            'payment_custom_field' => 'a:0:{}',
            'payment_method' => "Dobírka",
            'payment_code' => "1",
            'shipping_firstname' => $customer['firstname'],
            'shipping_lastname' => $customer['lastname'],
            'shipping_company' => "",
            'shipping_address_1' => $customer['address'],
            'shipping_address_2' => "",
            'shipping_city' => $customer['city'],
            'shipping_postcode' => $customer['postcode'],
            'shipping_country' => "Czech Republic",
            'shipping_country_id' => 56,
            'shipping_zone' => "",
            'shipping_zone_id' => 0,
            'shipping_address_format' => "",
            'shipping_custom_field' => 'a:0:{}',
            'shipping_method' => "CP",
            'shipping_code' => "1",
            'comment' => $customer['comment'],
            'total' => $total,
            'order_status_id' => 1,
            'affiliate_id' => 0,
            'commission' => 0,
            'marketing_id' => 0,
            'tracking' => "",
            'language_id' => 1,
            'currency_id' => 2,
            'currency_code' => "CZK",
            'currency_value' => 1,
            'ip' => $customer['ip'],
            'forwarded_ip' => "",
            'user_agent' => $customer['user_agent'],
            'accept_language' => $customer['accept_language'],
            'date_added' => new \DateTime(),
            'date_modified' => new \DateTime(),
        );


        $this->db->beginTransaction();
        $new_order = $this->db->table('oc_order')->insert($order);
        $this->data['order_id'] = $new_order['order_id'];
        $this->insertProducts($products);

        //$this->generateRandomSymbol($new_order['order_id']);

        $this->db->commit();

        return $new_order['order_id'];
    }

    private function loadConfig()
    {
        $this->config = array();
        $res = $this->db->table('oc_setting')->fetchAll();
        foreach ($res as $row) {
            $this->config[$row['key']] = $row['value'];
        }
    }

    /**
     * @param $products array of products
     */
    private function insertProducts($products)
    {
        $order_id = $this->data['order_id'];
        $res = $this->productModel->getProductInfoIn($this->lang, $this->ids);
        $data = array();
        $total_product_price = 0;
        foreach ($res as $product) {
            $data[$product['product_id']] = $product;
        }

        foreach ($products as $basket_product) {

            $product_id = $basket_product['id'];

            $quantity = $basket_product['quantity'];

            $total_product_price += $quantity * $data[$product_id]['price'];

            $row = array(
                'order_id' => $order_id,
                'product_id' => $product_id,
                'name' => $data[$product_id]['name'],
                'model' => $data[$product_id]['model'],
                'quantity' => $quantity,
                'price' => $data[$product_id]['price'],
                'total' => $quantity * $data[$product_id]['price'],
                'tax' => $data[$product_id]['tax_rate'],
                'reward' => 0,
            );
            $this->db->table('oc_order_product')->insert($row);

        }
        $this->insertOrderTotal($total_product_price);
    }

    private function insertOrderTotal($products_price)
    {
        $order_id = $this->data['order_id'];
        $shipping_payment_price = 0;
        $product_row = array(
            'order_id' => $order_id,
            'code' => 'sub_total',
            'title' => 'Cena zboží',
            'value' => $products_price,
            'sort_order' => 1,
        );
        $shipping_row = array(
            'order_id' => $order_id,
            'code' => 'shipping',
            'title' => "Poštovné",
            'value' => $shipping_payment_price,
            'sort_order' => 3,
        );
        $total_row = array(
            'order_id' => $order_id,
            'code' => 'total',
            'title' => 'Celkem',
            'value' => $products_price + $shipping_payment_price,
            'sort_order' => 9,
        );
        $this->db->table('oc_order_total')->insert($product_row);
        $this->db->table('oc_order_total')->insert($shipping_row);
        $this->db->table('oc_order_total')->insert($total_row);
        $update_order = array(
            'total' => $products_price + $shipping_payment_price,
        );
        $this->db->table('oc_order')->where('order_id', $order_id)->update($update_order);
    }


    public
    function testCall()
    {
        $products = array(
            '50' => array(
                'id' => '50',
                'quantity' => 1,
            ),
        );
        $customer = array(
            'firstname' => "Tomáš",
            'lastname' => "Kozák",
            'telephone' => "720 138 195",
            'email' => "kozak@talocko.cz",
            'address' => "Veselice 12",
            'city' => "Vavřinec",
            'postcode' => 67913,
            'comment' => "Poznámka",
            'ip' => "192.168.1.103",
            'user_agent' => "Chrome",
            'accept_language' => "Čeština",
        );

        $this->createOrder('en', $products, $customer);
    }



    public function generateRandomSymbol($order_id, $change = FALSE)
    {
        if ($change) {

            $row = $this->db->query("SELECT payment_code FROM oc_order WHERE order_id = ?", $order_id)->fetch();
            if (!$row) {
                throw new BadRequestException;
            }
            if (self::CREDIT_CARD !== intval($row['payment_code'])) { // staticky variabilni symbol
                return;
            }
        }
        try {
            $now = new \DateTime();
            $vs = $now->format('ymd') . $this->getVsIterator();
            $this->db->table('oc_order')->where('order_id', $order_id)->where('payment_status', 0)->update(array('payment_symbol' => $vs));
        } catch (\Exception $e) {
            if ($e->getCode() === '23000') {
                $this->generateRandomSymbol($order_id);
            } else {
                throw $e;
            }
        }
    }

    private function getVsIterator()
    {
        $vs = str_pad(rand(1,9999), 4, "0", STR_PAD_LEFT);
        return $vs;
    }
}