<?php

namespace OpencartAPI\Server\Model\Product;

use OpencartAPI\Server\Model\BaseManager;

class ProductManager extends BaseManager
{

    public function getProductById($language, $product_id)
    {
        $product = $this->db->query("
           SELECT
              oc_product.product_id,
              oc_product.model,
              oc_product.sku,
              oc_product.ean,
              oc_product.quantity,
              oc_product.image,
              oc_product.manufacturer_id,
              oc_product.price,
              oc_product.date_available,
              oc_product_description.name,
              oc_product_description.description,
              oc_product_description.meta_title,
              oc_product_description.meta_keyword,
              oc_language.code,
              oc_manufacturer.name  AS manufacturer_name,
              oc_manufacturer.image AS manufacturer_image,
              oc_tax_rate.rate      AS tax_rate,
              oc_tax_rate.name      AS tax_name,
              oc_tax_rate.type      AS tax_type
            FROM oc_product
              JOIN oc_product_description
                ON oc_product.product_id = oc_product_description.product_id
              JOIN oc_language
                ON oc_language.language_id = oc_product_description.language_id
              LEFT JOIN oc_manufacturer
                ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
              JOIN oc_tax_class
                ON oc_tax_class.tax_class_id = oc_product.tax_class_id
              JOIN oc_tax_rule
                ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
              JOIN oc_tax_rate
                ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
            WHERE oc_product.product_id = ?
                  AND oc_product.status = 1
                  AND oc_language.code = ?;

        ", $product_id, $language)->fetch();
        if (!$product) {
            return FALSE;
        }

        return (array)$product;
    }

    public function getProductInfoIn($language, $ids)
    {
        $product = $this->db->query("
           SELECT
              oc_product.product_id,
              oc_product.model,
              oc_product.sku,
              oc_product.ean,
              oc_product.quantity,
              oc_product.image,
              oc_product.manufacturer_id,
              oc_product.price,
              oc_product.date_available,
              oc_product_description.name,
              oc_product_description.description,
              oc_product_description.meta_title,
              oc_product_description.meta_keyword,
              oc_language.code,
              oc_manufacturer.name  AS manufacturer_name,
              oc_manufacturer.image AS manufacturer_image,
              oc_tax_rate.rate      AS tax_rate,
              oc_tax_rate.name      AS tax_name,
              oc_tax_rate.type      AS tax_type
            FROM oc_product
              JOIN oc_product_description
                ON oc_product.product_id = oc_product_description.product_id
              JOIN oc_language
                ON oc_language.language_id = oc_product_description.language_id
              LEFT JOIN oc_manufacturer
                ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
              JOIN oc_tax_class
                ON oc_tax_class.tax_class_id = oc_product.tax_class_id
              JOIN oc_tax_rule
                ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
              JOIN oc_tax_rate
                ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
            WHERE oc_product.product_id IN (?)
                  AND oc_product.status = 1
                  AND oc_language.code = ?;

        ", $ids, $language)->fetchAll();
        if (!$product) {
            return FALSE;
        }

        return (array)$product;
    }

    public function getProductAttributes($language, $product_id)
    {
        $res = $this->db->query("
            SELECT
              oc_attribute_description.name,
              oc_product_attribute.text
            FROM oc_product_attribute
              JOIN oc_attribute
                ON oc_attribute.attribute_id = oc_product_attribute.attribute_id
              JOIN oc_attribute_description
                ON oc_attribute_description.attribute_id = oc_attribute.attribute_id
              JOIN oc_language
                ON oc_language.language_id = oc_product_attribute.language_id AND
                   oc_language.language_id = oc_attribute_description.language_id
            WHERE oc_language.code = ?
                  AND oc_product_attribute.product_id = ?;
        ", $language, $product_id)->fetchAll();

        $attributes = ['data' => []];
        foreach ($res as $row) {
            $attributes['data'][$row['name']] = $row['text'];
        }

        return $attributes;
    }

    public function getProductImages($product_id)
    {
        $res = $this->db->query("
            SELECT image
                FROM oc_product_image
                WHERE product_id = ?
                ORDER BY sort_order;
        ", $product_id)->fetchAll();

        $images = ['data' => []];
        foreach ($res as $row) {
            array_push($images['data'], $row['image']);
        }
        return $images;
    }

    public function getProductsInCategory($language, $category_id)
    {
        $res = $this->db->query("
            SELECT
              oc_product.product_id,
              oc_product.model,
              oc_product.sku,
              oc_product.ean,
              oc_product.quantity,
              oc_product.image,
              oc_product.manufacturer_id,
              oc_product.price,
              oc_product.date_available,
              oc_product_description.name,
              oc_product_description.description,
              oc_product_description.meta_title,
              oc_product_description.meta_keyword,
              oc_language.code,
              oc_manufacturer.name  AS manufacturer_name,
              oc_manufacturer.image AS manufacturer_image,
              oc_tax_rate.rate      AS tax_rate,
              oc_tax_rate.name      AS tax_name,
              oc_tax_rate.type      AS tax_type
            FROM oc_product
              JOIN oc_product_description
                ON oc_product.product_id = oc_product_description.product_id
              JOIN oc_language
                ON oc_language.language_id = oc_product_description.language_id
              LEFT JOIN oc_manufacturer
                ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
              JOIN oc_tax_class
                ON oc_tax_class.tax_class_id = oc_product.tax_class_id
              JOIN oc_tax_rule
                ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
              JOIN oc_tax_rate
                ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
              JOIN oc_product_to_category
                ON oc_product_to_category.product_id = oc_product.product_id
            WHERE oc_product_to_category.category_id IN (
              SELECT oc_category_path.category_id
              FROM oc_category_path
              WHERE path_id = ?
            )
                  AND oc_product.status = 1
                  AND oc_language.code = ?;
        ", $category_id, $language)->fetchAll();

        $products = [];
        foreach ($res as $row) {
            array_push($products, (array)$row);
        }

        return $products;
    }

    public function getProductsInFilter($language, $filter_name)
    {
        $res = $this->db->query("
            SELECT
              oc_product.product_id,
              oc_product.model,
              oc_product.sku,
              oc_product.ean,
              oc_product.quantity,
              oc_product.image,
              oc_product.manufacturer_id,
              oc_product.price,
              oc_product.date_available,
              oc_product_description.name,
              oc_product_description.description,
              oc_product_description.meta_title,
              oc_product_description.meta_keyword,
              oc_language.code,
              oc_manufacturer.name  AS manufacturer_name,
              oc_manufacturer.image AS manufacturer_image,
              oc_tax_rate.rate      AS tax_rate,
              oc_tax_rate.name      AS tax_name,
              oc_tax_rate.type      AS tax_type
            FROM oc_product
              JOIN oc_product_description
                ON oc_product.product_id = oc_product_description.product_id
              JOIN oc_language
                ON oc_language.language_id = oc_product_description.language_id
              JOIN oc_manufacturer
                ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
              JOIN oc_tax_class
                ON oc_tax_class.tax_class_id = oc_product.tax_class_id
              JOIN oc_tax_rule
                ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
              JOIN oc_tax_rate
                ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
              JOIN oc_product_filter
                ON oc_product_filter.product_id = oc_product.product_id
              JOIN oc_filter
                ON oc_filter.filter_id = oc_product_filter.filter_id
              JOIN oc_filter_description
                ON oc_filter_description.filter_id = oc_filter.filter_id
            WHERE oc_product.status = 1
                  AND oc_language.code = ?
                  AND oc_filter_description.name = ?
        ", $language, $filter_name)->fetchAll();

        $products = [];
        foreach ($res as $row) {
            array_push($products, (array)$row);
        }

        return $products;
    }

}