/* Get all categories */
SELECT
  oc_category.category_id,
  oc_category.image,
  oc_category.parent_id,
  oc_category_description.name,
  oc_category_description.description,
  oc_category_description.meta_title,
  oc_category_description.meta_description,
  oc_category_description.meta_keyword
FROM oc_category
  JOIN oc_category_description
    ON oc_category.category_id = oc_category_description.category_id
  JOIN oc_language
    ON oc_language.language_id = oc_category_description.language_id
WHERE oc_language.code = 'en'
      AND oc_category.status = 1;

/* Get categories structure */
SELECT
  oc_category_path.category_id,
  oc_category_path.path_id,
  oc_category_path.level
FROM oc_category_path
  JOIN oc_category
    ON oc_category_path.category_id = oc_category.category_id
WHERE oc_category.status = 1
      AND oc_category_path.category_id = 35
ORDER BY oc_category_path.level, oc_category.sort_order;

/* Get product by ID */
SELECT
  oc_product.product_id,
  oc_product.model,
  oc_product.sku,
  oc_product.ean,
  oc_product.quantity,
  oc_product.image,
  oc_product.manufacturer_id,
  oc_product.price,
  oc_product.date_available,
  oc_product_description.name,
  oc_product_description.description,
  oc_product_description.meta_title,
  oc_product_description.meta_keyword,
  oc_language.code,
  oc_manufacturer.name  AS manufacturer_name,
  oc_manufacturer.image AS manufacturer_image,
  oc_tax_rate.rate      AS tax_rate,
  oc_tax_rate.name      AS tax_name,
  oc_tax_rate.type      AS tax_type
FROM oc_product
  JOIN oc_product_description
    ON oc_product.product_id = oc_product_description.product_id
  JOIN oc_language
    ON oc_language.language_id = oc_product_description.language_id
  JOIN oc_manufacturer
    ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
  JOIN oc_tax_class
    ON oc_tax_class.tax_class_id = oc_product.tax_class_id
  JOIN oc_tax_rule
    ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
  JOIN oc_tax_rate
    ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
WHERE oc_product.product_id = '30'
      AND oc_product.status = 1
      AND oc_language.code = 'en';

/* Get products in category */
SELECT
  oc_product.product_id,
  oc_product.model,
  oc_product.sku,
  oc_product.ean,
  oc_product.quantity,
  oc_product.image,
  oc_product.manufacturer_id,
  oc_product.price,
  oc_product.date_available,
  oc_product_description.name,
  oc_product_description.description,
  oc_product_description.meta_title,
  oc_product_description.meta_keyword,
  oc_language.code,
  oc_manufacturer.name  AS manufacturer_name,
  oc_manufacturer.image AS manufacturer_image,
  oc_tax_rate.rate      AS tax_rate,
  oc_tax_rate.name      AS tax_name,
  oc_tax_rate.type      AS tax_type
FROM oc_product
  JOIN oc_product_description
    ON oc_product.product_id = oc_product_description.product_id
  JOIN oc_language
    ON oc_language.language_id = oc_product_description.language_id
  JOIN oc_manufacturer
    ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
  JOIN oc_tax_class
    ON oc_tax_class.tax_class_id = oc_product.tax_class_id
  JOIN oc_tax_rule
    ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
  JOIN oc_tax_rate
    ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
  JOIN oc_product_to_category
    ON oc_product_to_category.product_id = oc_product.product_id
WHERE oc_product_to_category.category_id IN (
  SELECT oc_category_path.category_id
  FROM oc_category_path
  WHERE path_id = 25
)
      AND oc_product.status = 1
      AND oc_language.code = 'en';

/* Get product images */
SELECT image
FROM oc_product_image
WHERE product_id = 30
ORDER BY sort_order;

/* Get product attributes */
SELECT
  oc_attribute_description.name,
  oc_product_attribute.text
FROM oc_product_attribute
  JOIN oc_attribute
    ON oc_attribute.attribute_id = oc_product_attribute.attribute_id
  JOIN oc_attribute_description
    ON oc_attribute_description.attribute_id = oc_attribute.attribute_id
  JOIN oc_language
    ON oc_language.language_id = oc_product_attribute.language_id AND
       oc_language.language_id = oc_attribute_description.language_id
WHERE oc_language.code = 'en'
      AND oc_product_attribute.product_id = '42';

/* Get product in filter */
SELECT
  oc_product.product_id,
  oc_product.model,
  oc_product.sku,
  oc_product.ean,
  oc_product.quantity,
  oc_product.image,
  oc_product.manufacturer_id,
  oc_product.price,
  oc_product.date_available,
  oc_product_description.name,
  oc_product_description.description,
  oc_product_description.meta_title,
  oc_product_description.meta_keyword,
  oc_language.code,
  oc_manufacturer.name  AS manufacturer_name,
  oc_manufacturer.image AS manufacturer_image,
  oc_tax_rate.rate      AS tax_rate,
  oc_tax_rate.name      AS tax_name,
  oc_tax_rate.type      AS tax_type
FROM oc_product
  JOIN oc_product_description
    ON oc_product.product_id = oc_product_description.product_id
  JOIN oc_language
    ON oc_language.language_id = oc_product_description.language_id
  JOIN oc_manufacturer
    ON oc_manufacturer.manufacturer_id = oc_product.manufacturer_id
  JOIN oc_tax_class
    ON oc_tax_class.tax_class_id = oc_product.tax_class_id
  JOIN oc_tax_rule
    ON oc_tax_rule.tax_class_id = oc_tax_class.tax_class_id
  JOIN oc_tax_rate
    ON oc_tax_rate.tax_rate_id = oc_tax_rule.tax_rate_id
  JOIN oc_product_filter
    ON oc_product_filter.product_id = oc_product.product_id
  JOIN oc_filter
    ON oc_filter.filter_id = oc_product_filter.filter_id
  JOIN oc_filter_description
    ON oc_filter_description.filter_id = oc_filter.filter_id
WHERE oc_product.status = 1
      AND oc_language.code = 'en'
      AND oc_filter_description.name = 'Homepage';