<?php

namespace Pogodi\Scud;


use Nette\Database\Context;
use Nette\Object;
use Nette\Utils\DateTime;
use Pogodi\Scud\Entity\AccessToken;

class AccessTokenManager extends Object
{

    const
        TABLE_NAME = 'access',
        COLUMN_ID = 'id',
        COLUMN_USER_ID = 'user_id',
        COLUMN_KEY = 'key',
        COLUMN_EXPIRATION = 'expiration',
        COLUMN_ACTIVE = 'active';

    /**
     * @var Context
     */
    private $database;

    /**
     * @param Context $context
     */
    public function __construct(Context $context)
    {
        $this->database = $context;
    }

    /**
     * @param int $user_id
     * @return AccessToken
     */
    public function generate($user_id)
    {
        $token = new AccessToken();
        $data = [
            self::COLUMN_USER_ID => $user_id,
            self::COLUMN_KEY => $token->getKey(),
            self::COLUMN_EXPIRATION => $token->getExpiration(),
            self::COLUMN_ACTIVE => 1,
        ];
        $this->database->table(self::TABLE_NAME)->insert($data);
        return $token;
    }

    public function deactivate($key)
    {
        $data = [
            self::COLUMN_ACTIVE => 0,
        ];
        $this->database->table(self::TABLE_NAME)->where([
            self::COLUMN_KEY => $key,
            self::COLUMN_ACTIVE => 1,
        ])->update($data);
    }

    /**
     * @param $key
     * @return AccessToken
     */
    public function getByKey($key)
    {
        $row = $this->database->table(self::TABLE_NAME)->where([
            self::COLUMN_KEY => $key,
            self::COLUMN_ACTIVE => 1,
        ])->fetch();
        if (!$row) {
            return new AccessToken("", new DateTime(), FALSE); // bad AccessToken
        }
        return new AccessToken($row[self::COLUMN_KEY], $row[self::COLUMN_EXPIRATION], $row[self::COLUMN_ACTIVE]);
    }

}