<?php

namespace Pogodi\Scud;


use Nette\Database\Context;
use Nette\Object;
use Pogodi\Scud\Entity\Application;

class ApplicationManager extends Object
{

    const
        PERMISSIONS_TABLE_NAME = 'permissions',
        COLUMN_USER_ID = 'user_id',
        COLUMN_APPLICATION_ID = 'application_id',

        APPLICATION_TABLE_NAME = 'application',
        COLUMN_ID = 'id',
        COLUMN_NAME = 'name',
        COLUMN_SCUD_URL = 'scudUrl',
        COLUMN_ACTIVE = 'active';

    /**
     * @var Context
     */
    private $database;

    /**
     * @param Context $database
     */
    public function __construct(Context $database)
    {
        $this->database = $database;
    }

    public function getAllApplications()
    {
        $return = [];
        $res = $this->database->table(self::APPLICATION_TABLE_NAME)->where([self::COLUMN_ACTIVE => 1]);
        foreach ($res as $application) {
            array_push($return, new Application(intval($application[self::COLUMN_ID]), $application[self::COLUMN_NAME], $application[self::COLUMN_SCUD_URL]));
        }
        return $return;
    }

    public function getAllowedApplications($user_id)
    {
        $return = [];
        $res = $this->database->table(self::PERMISSIONS_TABLE_NAME)->where([self::COLUMN_USER_ID => $user_id]);
        foreach ($res as $row) {
            $application = $row->ref(self::APPLICATION_TABLE_NAME, self::COLUMN_APPLICATION_ID);
            if (1 == intval($application->active)) {
                array_push($return, new Application(intval($application[self::COLUMN_ID]), $application[self::COLUMN_NAME], $application[self::COLUMN_SCUD_URL]));
            }
        }
        return $return;
    }

    /**
     * @param int $user_id
     * @param int $application_id
     * @return bool
     */
    public function isAllow($user_id, $application_id)
    {
        $count = $this->database->table(self::PERMISSIONS_TABLE_NAME)->where([
            self::COLUMN_USER_ID => $user_id,
            self::COLUMN_APPLICATION_ID => $application_id,
        ])->count();
        return ($count) ? TRUE : FALSE;
    }


    public function getApplicationById($application_id)
    {
        $res = $this->database->table(self::APPLICATION_TABLE_NAME)->where([
            self::COLUMN_ID => $application_id,
            self::COLUMN_ACTIVE => 1,
        ])->fetch();
        if (!$res) {
            throw new \InvalidArgumentException("Application with id '$application_id' not found");
        }
        return new Application(intval($res[self::COLUMN_ID]), $res[self::COLUMN_NAME], $res[self::COLUMN_SCUD_URL]);
    }

    public function getApplicationByName($application_name)
    {
        $res = $this->database->table(self::APPLICATION_TABLE_NAME)->where([
            self::COLUMN_NAME => $application_name,
            self::COLUMN_ACTIVE => 1,
        ])->fetch();
        if (!$res) {
            throw new \InvalidArgumentException("Application with name '$application_name' not found");
        }
        return new Application(intval($res[self::COLUMN_ID]), $res[self::COLUMN_NAME], $res[self::COLUMN_SCUD_URL]);
    }
}