<?php

namespace Pogodi\Scud;

use Nette,
    Nette\Security\Passwords;
use Nette\Database\Table\IRow;
use Nette\Utils\DateTime;


/**
 * Users management.
 */
class UserManager extends Nette\Object implements Nette\Security\IAuthenticator
{
    const
        TABLE_NAME = 'user',
        COLUMN_ID = 'id',
        COLUMN_EMAIL = 'email',
        COLUMN_PASSWORD_HASH = 'password',
        COLUMN_ACTIVE = 'active',
        COLUMN_CREATED = 'created',
        COLUMN_ROOT = 'root';


    /** @var Nette\Database\Context */
    private $database;


    public function __construct(Nette\Database\Context $database)
    {
        $this->database = $database;
    }


    /**
     * Performs an authentication.
     * @return Nette\Security\Identity
     * @throws Nette\Security\AuthenticationException
     */
    public function authenticate(array $credentials)
    {
        list($email, $password) = $credentials;

        $row = $this->getOne([self::COLUMN_EMAIL => $email]);
        if (!$row) {
            throw new Nette\Security\AuthenticationException("User not found.");
        }
        if (!Passwords::verify($password, $row[self::COLUMN_PASSWORD_HASH])) {
            throw new Nette\Security\AuthenticationException("Bad password.");
        }

        $data = $row->toArray();
        unset($data[self::COLUMN_PASSWORD_HASH]);
        return new Nette\Security\Identity($data[self::COLUMN_ID], ['root' => $data[self::COLUMN_ROOT]], $data);
    }


    /**
     * @param string $email
     * @param string $password
     * @param bool|int $root
     * @return int
     */
    public function add($email, $password, $root = 0)
    {
        $row = $this->database->table(self::TABLE_NAME)->insert([
            self::COLUMN_EMAIL => $email,
            self::COLUMN_PASSWORD_HASH => Passwords::hash($password),
            self::COLUMN_ACTIVE => TRUE,
            self::COLUMN_CREATED => new DateTime(),
            self::COLUMN_ROOT => $root,
        ]);
        return intval($row[self::COLUMN_ID]);
    }

    /**
     * @param array $where
     * @return bool|mixed|IRow
     */
    public function getOne(array $where)
    {
        return $this->database->table(self::TABLE_NAME)->where($where)->fetch();
    }

    /**
     * @param $id
     * @return int
     */
    public function delete($id)
    {
        return $this->database->table(self::TABLE_NAME)->where([self::COLUMN_ID => $id])->delete();
    }

}
