<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Pogodi\Scud\AccessTokenManager;
use Pogodi\Scud\Entity\AccessToken;
use Pogodi\Scud\UserManager;
use Tester\Assert;
use Tester\Environment;

/** @var Container $container */
$container = require __DIR__ . "/../bootstrap.php";
Environment::lock('database', LOCK_DIR);

/** @var UserManager $userManager */
$userManager = $container->getByType('Pogodi\Scud\UserManager');

/** @var AccessTokenManager $tokenManager */
$tokenManager = $container->getByType('Pogodi\Scud\AccessTokenManager');

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');


Helpers::loadFromFile($connection, __DIR__ . "/test_sql/tables_data.sql");
$user_id = $userManager->add("john@doe.com", "password_01", 1);

$token = $tokenManager->generate($user_id);
Assert::true(strlen($token->getKey()) == AccessToken::KEY_LENGHT);
Assert::true($token->isOk());

$tokenFromDb = $tokenManager->getByKey($token->getKey());
Assert::true(strlen($tokenFromDb->getKey()) == AccessToken::KEY_LENGHT);
Assert::true($tokenFromDb->isOk());

$tokenManager->deactivate($token->getKey());
$deactivatedTokenFromDb = $tokenManager->getByKey($token->getKey());
Assert::false($deactivatedTokenFromDb->isOk());

$tokenFromDb = $tokenManager->getByKey("THIS KEY NOT EXIST");
Assert::false($tokenFromDb->isOk());