<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Pogodi\Scud\ApplicationManager;
use Pogodi\Scud\Entity\Application;
use Tester\Assert;
use Tester\Environment;

/** @var Container $container */
$container = require __DIR__ . "/../bootstrap.php";
Environment::lock('database', LOCK_DIR);

/** @var ApplicationManager $applicationManager */
$applicationManager = $container->getByType('Pogodi\Scud\ApplicationManager');

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');


Helpers::loadFromFile($connection, __DIR__ . "/test_sql/tables_data_2.sql");

$apps = $applicationManager->getAllowedApplications(1); // 1 - user_id
Assert::true(is_array($apps));
Assert::true(count($apps) == 1);

/** @var Application $app */
$app = $apps['0'];
Assert::equal("cron", $app->getName());
Assert::equal("http://cron.pogodi.l", $app->getScudURL());
Assert::equal(2, $app->getId());

Assert::true($applicationManager->isAllow(1, 2));
Assert::false($applicationManager->isAllow(1, 1));
Assert::false($applicationManager->isAllow(3, 5));

$app_brain = $applicationManager->getApplicationById(1);
Assert::same(1, $app_brain->getId());
Assert::same("brain", $app_brain->getName());
Assert::same("http://brain.pogodi.l", $app_brain->getScudURL());

$app_cron = $applicationManager->getApplicationById(2);
Assert::same(2, $app_cron->getId());
Assert::same("cron", $app_cron->getName());
Assert::same("http://cron.pogodi.l", $app_cron->getScudURL());

Assert::exception(function () use ($applicationManager) {
    $applicationManager->getApplicationById(3);
}, 'InvalidArgumentException');

Assert::exception(function () use ($applicationManager) {
    $applicationManager->getApplicationById(999);
}, 'InvalidArgumentException');

$app = $applicationManager->getApplicationByName('brain');
Assert::equal('brain', $app->getName());
Assert::true(strlen($app->getScudURL()) > 0);

Assert::exception(function () use ($applicationManager) {
    $applicationManager->getApplicationByName('fail');
}, 'InvalidArgumentException');

Assert::exception(function () use ($applicationManager) {
    $applicationManager->getApplicationByName('test');
}, 'InvalidArgumentException');

$apps = $applicationManager->getAllApplications();
Assert::equal(2, count($apps));

Assert::true($apps[0] instanceof Application);
Assert::true($apps[1] instanceof Application);