<?php

use Nette\Database\Connection;
use Nette\Database\Context;
use Nette\Database\Helpers;
use Nette\DI\Container;
use Nette\Security\Identity;
use Pogodi\Scud\UserManager;
use Tester\Assert;
use Tester\Environment;

/** @var Container $container */
$container = require __DIR__ . "/../bootstrap.php";
Environment::lock('database', LOCK_DIR);

/** @var UserManager $userManager */
$userManager = $container->getByType('Pogodi\Scud\UserManager');

/** @var Context $databaseContext */
$databaseContext = $container->getByType('Nette\Database\Context');

/** @var Connection $connection */
$connection = $container->getByType('Nette\Database\Connection');


Helpers::loadFromFile($connection, __DIR__ . "/test_sql/tables_data.sql");

$id = $userManager->add("john@doe.com", "password_01", 1);
Assert::same(1, $id);
$row = $userManager->getOne(['id' => 1]);
Assert::same("john@doe.com", $row['email']);
Assert::true(strlen($row['password']) > 0);
Assert::same(1, $row['root']);

$id = $userManager->add("john2@doe2.com", "password_02", 0);
Assert::same(2, $id);
$row = $userManager->getOne(['id' => 2]);
Assert::same("john2@doe2.com", $row['email']);
Assert::true(strlen($row['password']) > 0);
Assert::same(0, $row['root']);

$row = $userManager->getOne(['id' => '457']);
Assert::same(FALSE, $row);

$userManager->delete(1);
$row = $userManager->getOne(['id' => 1]);
Assert::same(FALSE, $row);

Assert::exception(function () use ($userManager) {
    $credentials = ['notexistuser@asdasd.com', 'BAD PASSWORD'];
    $userManager->authenticate($credentials);
}, 'Nette\Security\AuthenticationException', "User not found.");

Assert::exception(function () use ($userManager) {
    $credentials = ['john2@doe2.com', 'BAD PASSWORD'];
    $userManager->authenticate($credentials);
}, 'Nette\Security\AuthenticationException', "Bad password.");

$credentials = ['john2@doe2.com', 'password_02'];
/** @var Identity $identity */
$identity = $userManager->authenticate($credentials);
Assert::true($identity instanceof Identity);
$roles = $identity->getRoles();
Assert::same(0, $roles['root']);

$data = $identity->getData();
Assert::same("john2@doe2.com", $data['email']);
Assert::same(0, $data['root']);
Assert::false(isset($data['password']));