<?php

namespace Pogodi\Site\Basket;


use Nette\Http\Session;
use Nette\Http\SessionSection;
use Nette\Object;
use Pogodi\Site\OpenCart\Service\Product;

class BasketService extends Object
{

    const BASKET_SECTION = 'basket_section';

    /**
     * @var SessionSection
     */
    private $section;

    /**
     * @var Product
     */
    private $productService;

    /**
     * @param Session $session
     * @param Product $productService
     */
    public function __construct(Session $session, Product $productService)
    {
        $this->section = $session->getSection(self::BASKET_SECTION);
        $this->productService = $productService;
    }

    /**
     * @return Basket
     */
    public function getBasket()
    {
        if (!($this->section->basket instanceof Basket)) {
            $this->section->basket = new Basket();
        }

        return $this->section->basket;
    }

    public function getProducts($language)
    {
        $return = array();
        $basket = $this->getBasket();
        foreach ($basket->getItems() as $item) {
            /** @var $item BasketItem */
            $return[] = array(
                'id' => $item->getItemId(),
                'item' => $this->productService->getProductById($language, $item->getItemId()),
                'quantity' => $item->getQuantity(),
            );
        }

        return $return;
    }

    /**
     * Remove all items from basket
     */
    public function trashBasket()
    {
        $this->section->basket = new Basket();
    }
}