<?php

namespace Pogodi\Site\OpenCart\Api;


use Nette\Object;

class Caller extends Object
{

    const
        GET = 'GET',
        POST = 'POST';

    /** @var  string */
    private $protocol;

    /** @var  string */
    private $host;

    /** @var  string */
    private $username;

    /** @var  string */
    private $password;

    /**
     * @param boolean $secured
     * @param string $host
     * @param string $username
     * @param string $password
     */
    public function __construct($secured, $host, $username, $password)
    {
        $this->protocol = ($secured) ? "https://" : "http://";
        $this->host = $host;
        $this->username = $username;
        $this->password = $password;
    }

    public function call($method, $type, $service, $params = [])
    {
        $url = $this->protocol . $this->host . "/?presenter={$type}&action={$service}";
        if (count($params) > 0) {
            foreach ($params as $name => $value) {
                $url .= "&{$name}={$value}";
            }
        }

        $data = $this->send($method, $url, $params);
        $data = json_decode($data, TRUE);

        if ($data['error'] === false) {
            unset($data['error']);
        } else {
            // @todo throw Exception
        }

        return $data;
    }


    protected function send($method, $url, $params = [])
    {
        $rCurl = curl_init();
        if (self::GET === $method) {
            curl_setopt_array($rCurl, [
                CURLOPT_RETURNTRANSFER => 1,
                CURLOPT_URL => $url,
            ]);
        } elseif (self::POST === $method) {
            $sFields = "";
            foreach ($params as $key => $value) {
                $sFields .= $key . '=' . $value . '&';
            }
            rtrim($sFields, '&');
            curl_setopt($rCurl, CURLOPT_URL, $url);
            curl_setopt($rCurl, CURLOPT_POST, count($params));
            curl_setopt($rCurl, CURLOPT_POSTFIELDS, $sFields);
        }

        $sResp = curl_exec($rCurl);
        return $sResp;
    }


}