<?php

namespace Pogodi\Site\Presenters;


use Nette\Application\UI\Form;
use Pogodi\Site\OpenCart\Service\Order;

class BasketPresenter extends BasePresenter
{

    /** @var Order @inject */
    public $orderService;

    public function renderDefault()
    {
        $products = $this->basketService->getProducts(self::BASE_LANG);
        $this->template->products = $products;
    }

    public function createComponentBasketForm()
    {
        $form = new Form();
        $form->addText('name', 'Jméno');
        $form->addText('surname', 'Příjmení');
        $form->addText('street', 'Ulice');
        $form->addText('city', 'Město');
        $form->addText('postcode', 'PSČ');
        $form->addText('email', 'Email');
        $form->addText('phone', 'Telefon');
        $form->addTextArea('note', 'Poznámka');
        $form->addSubmit('ok', 'ODESLAT OBJEDNÁVKU');
        $form->onSuccess[] = array($this, 'basketFormSubmitted');
        return $form;
    }

    public function basketFormSubmitted(Form $form)
    {
        $values = $form->getValues();
        $basket = $this->basketService->getBasket();

        $basket->setName($values->name);
        $basket->setSurname($values->surname);
        $basket->setStreet($values->street);
        $basket->setCity($values->city);
        $basket->setPostcode($values->postcode);
        $basket->setEmail($values->email);
        $basket->setPhone($values->phone);
        $basket->setNote($values->note);

        $this->orderService->createOrder(self::BASE_LANG, $basket);
        $this->flashMessage('Order has been successful.');
        $this->basketService->trashBasket();
        $this->redirect('Homepage:default');
    }

    public function handleRemoveItem($product_id)
    {
        $basket = $this->basketService->getBasket();
        $basket->removeItem((int)$product_id);
        $this->redrawControl();
    }

}