<?php

class Node
{
    /** @var  string */
    public $name;
    /** @var  int */
    public $id;
    /** @var Node */
    public $parent;
    /** @var array */
    public $children = [];
    /** @var int */
    public $level = 99;

    public function __construct($name, $parent)
    {
        $this->name = $name;
        $this->parent = $parent;
    }

    public function addChild($name, $parent)
    {
        foreach ($this->children as $key => $child) {
            /** @var Node $child */
            if ($name === $child->name) {
                return $this->children[$key];
            }
        }
        $node = new Node($name, $parent);
        $this->children[] = $node;
        return $node;
    }

}

$dbh = new PDO("mysql:host=localhost;dbname=oc_api;charset=utf8", 'root', '');
$dbh->exec("set names utf8");

$dbh->query("TRUNCATE oc_product_to_category");
$dbh->query("TRUNCATE oc_category_description");
$dbh->query("TRUNCATE oc_category_path");
$dbh->query("TRUNCATE oc_category");

$query = "
SELECT
  p.product_id,
  i.id as import_id,
  pd.description,
  pd.name as title
FROM oc_product p
  JOIN oc_product_description pd
    ON p.product_id = pd.product_id AND pd.language_id = 1
  JOIN oc_import i
    ON p.product_id = i.oc_id
";

$res = $dbh->query($query)->fetchAll();
$products = [];
$rootCategory = new Node("root", NULL);
$rootCategory->id = 0;
foreach ($res as $row) {
    $categories = explode("|", $row['description']);
    $c = [];
    $node = $rootCategory;
    foreach ($categories as $category) {
        $level = trim($category);
        $node = $node->addChild($level, $node);
        $c[] = $level;
    }
    $products[(int)$row['product_id']] = array(
        'categories' => $c,
        'import_id' => $row['import_id'],
        'title' => $row['title']
    );
}

function buildCategoryTree(Node $node, $level = 0)
{
    global $dbh;
    $node->level = $level;
    $pdb = $dbh->prepare("INSERT INTO oc_category (image, parent_id, top, `column`, sort_order, status, date_added, date_modified) VALUES
                          ('', :PARENT_ID, '0', '1', '0', '1', NOW(), NOW())");
    $pdb->bindParam('PARENT_ID', $node->parent->id);
    $pdb->execute();
    $pdb->closeCursor();
    $node->id = $dbh->lastInsertId();

    $pdb = $dbh->prepare("INSERT INTO oc_category_description (category_id, language_id, name, description, meta_title, meta_description, meta_keyword) VALUES
                          (:CATEGORY_ID, 1, :TITLE, :DESCRIPTION, :TITLE, '', '');");
    $pdb->bindParam('CATEGORY_ID', $node->id);
    $pdb->bindParam('TITLE', $node->name);
    $pdb->bindParam('DESCRIPTION', $node->name);
    $pdb->execute();
    $pdb->closeCursor();

    $path = $node;
    while ($path->parent !== NULL) {
        $pdb = $dbh->prepare("INSERT INTO oc_category_path (category_id, path_id, level) VALUES
        (:CATEGORY_ID, :PATH_ID, :CATEGORY_LEVEL)");
        $pdb->bindParam('CATEGORY_ID', $node->id);
        $pdb->bindParam('PATH_ID', $path->id);
        $pdb->bindParam('CATEGORY_LEVEL', $path->name);
        $pdb->execute();
        $pdb->closeCursor();
        $path = $path->parent;
    }

    foreach ($node->children as $child) {
        buildCategoryTree($child, $level + 1);
    }
}

foreach ($rootCategory->children as $child) {
    buildCategoryTree($child);
}


function findCategoryId(array $data, Node $node, $level = 0)
{
    $final_level = count($data) - 1;

    foreach ($node->children as $child) {
        /** @var Node $child */
        if ($child->name == $data[$level]) {
            if (($level) == $final_level) {
                return $child->id;
            } else {
                return findCategoryId($data, $child, $level + 1);
            }
        }
    }

}

$json = json_decode(file_get_contents(__DIR__ . "/data/export.json"), true);

foreach ($products as $product_id => $product) {
    $category_id = findCategoryId($product['categories'], $rootCategory);
    $pdb = $dbh->prepare("INSERT INTO oc_product_to_category (product_id, category_id) VALUE (:PRODUCT_ID, :CATEGORY_ID)");
    $pdb->bindParam('PRODUCT_ID', $product_id);
    $pdb->bindParam('CATEGORY_ID', $category_id);
    $pdb->execute();
    $pdb->closeCursor();

    $image = "";
    $description = "";
    foreach ($json as $json_product) {
        if ($json_product['PRODUCTNAME']['0'] === $product['title']) {
            $image = "catalog/images/" . $json_product['i'] . ".jpg";
            $description = $json_product['DESCRIPTION']['0'];
        }
    }

    $pdb = $dbh->prepare("UPDATE oc_product SET image = :IMAGE, stock_status_id = 7, status = 1 WHERE product_id = :PRODUCT_ID");
    $pdb->bindParam('IMAGE', $image);
    $pdb->bindParam('PRODUCT_ID', $product_id);
    $pdb->execute();
    $pdb->closeCursor();

    $pdb = $dbh->prepare("UPDATE oc_product_description SET description = :DESCRIPTION WHERE product_id = :PRODUCT_ID");
    $pdb->bindParam('DESCRIPTION', $description);
    $pdb->bindParam('PRODUCT_ID', $product_id);
    //$pdb->execute();
    //$pdb->closeCursor();
}


function echoCat(Node $node, $level = 0)
{
    echo str_repeat(" ", $level * 2);
    echo $node->name . "\n";
    foreach ($node->children as $ch) {
        echoCat($ch, $level + 1);
    }
}
